@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2016-2021, 2023 Arm Limited.
+ * Copyright (c) 2016-2021, 2023, 2025 Arm Limited.
  *
  * SPDX-License-Identifier: MIT
  *
@@ -21,8 +21,12 @@
  * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
  * SOFTWARE.
  */
-#ifndef ARM_COMPUTE_ICLARRAY_H
-#define ARM_COMPUTE_ICLARRAY_H
+#ifndef ACL_ARM_COMPUTE_CORE_CL_ICLARRAY_H
+#define ACL_ARM_COMPUTE_CORE_CL_ICLARRAY_H
+
+/** @file
+ * @publicapi
+ */
 
 #include "arm_compute/core/CL/OpenCL.h"
 #include "arm_compute/core/IArray.h"
@@ -125,4 +129,4 @@ using ICLInt32Array = ICLArray<cl_int>;
 /** Interface for OpenCL Array of floats. */
 using ICLFloatArray = ICLArray<cl_float>;
 } // namespace arm_compute
-#endif /*ARM_COMPUTE_ICLARRAY_H*/
+#endif // ACL_ARM_COMPUTE_CORE_CL_ICLARRAY_H
