@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2016-2024 Arm Limited.
+ * Copyright (c) 2016-2025 Arm Limited.
  *
  * SPDX-License-Identifier: MIT
  *
@@ -24,6 +24,10 @@
 #ifndef ACL_ARM_COMPUTE_CORE_UTILS_DATATYPEUTILS_H
 #define ACL_ARM_COMPUTE_CORE_UTILS_DATATYPEUTILS_H
 
+/** @file
+ * @publicapi
+ */
+
 #include "arm_compute/core/PixelValue.h"
 #include "arm_compute/core/Types.h"
 
@@ -69,6 +73,35 @@ inline size_t data_size_from_type(DataType data_type)
     }
 }
 
+/** Get underlying data type
+ *
+ * @param[in] data_type Input data type
+ *
+ * @return the underlying data type
+ */
+inline constexpr DataType get_underlying_data_type(DataType data_type)
+{
+    switch (data_type)
+    {
+        case DataType::U8:
+        case DataType::QASYMM8:
+            return DataType::U8;
+        case DataType::S8:
+        case DataType::QSYMM8:
+        case DataType::QASYMM8_SIGNED:
+        case DataType::QSYMM8_PER_CHANNEL:
+            return DataType::S8;
+        case DataType::U16:
+        case DataType::QASYMM16:
+            return DataType::U16;
+        case DataType::S16:
+        case DataType::QSYMM16:
+            return DataType::S16;
+        default:
+            return data_type;
+    }
+}
+
 /** The size in bytes of the data type
  *
  * @param[in] dt Input data type
@@ -97,9 +130,12 @@ inline size_t element_size_from_data_type(DataType dt)
         case DataType::S32:
         case DataType::F32:
             return 4;
+        case DataType::F64:
         case DataType::U64:
         case DataType::S64:
             return 8;
+        case DataType::SIZET:
+            return sizeof(size_t); // portable
         default:
             ARM_COMPUTE_ERROR("Undefined element size for given data type");
             return 0;
