@@ -105,7 +105,8 @@ public:
           _activation_info(),
           _fixed_format(false),
           _weight_format(arm_compute::WeightFormat::UNSPECIFIED),
-          _accumulate(false)
+          _accumulate(false),
+          _use_fp32_acc(false)
     {
     }
     /** Constructor
@@ -127,6 +128,7 @@ public:
      * @param[in] weight_format               (Optional) arm_gemm:WeightFormat enumeration requested by the user. Default is arm_compute::WeightFormat::UNSPECIFIED.
      * @param[in] pretranspose_B              (Optional) Pretranspose matrix B (transposition of its lowest 2 dimensions), in addition to and before, any further transformations of B
      * @param[in] accumulate                  (Optional) Whether to accumulate in destination or not
+     * @param[in] use_fp32_acc                (Optional) Whether to use fp32 accumulation in fp16 matmul (applicable to fp16 matmul only, ignored in other configurations)
      */
     GEMMInfo(bool                       is_a_reshaped,
              bool                       is_b_reshaped,
@@ -142,7 +144,8 @@ public:
              bool                       fixed_format            = false,
              arm_compute::WeightFormat  weight_format           = arm_compute::WeightFormat::UNSPECIFIED,
              bool                       pretranspose_B          = false,
-             bool                       accumulate              = false) noexcept
+             bool                       accumulate              = false,
+             bool                       use_fp32_acc            = false) noexcept
         : _is_a_reshaped(is_a_reshaped),
           _is_b_reshaped(is_b_reshaped),
           _reshape_b_only_on_first_run(reshape_b_only_on_first_run),
@@ -158,7 +161,8 @@ public:
           _activation_info(activation_info),
           _fixed_format(fixed_format),
           _weight_format(weight_format),
-          _accumulate(accumulate)
+          _accumulate(accumulate),
+          _use_fp32_acc(use_fp32_acc)
     {
     }
     /** Flag which specifies if the matrix A has been reshaped
@@ -342,6 +346,10 @@ public:
         _accumulate = accumulate;
     }
 
+    /** Weight format to be used
+     *
+     * @return The selected weight format.
+     */
     arm_compute::WeightFormat weight_format() const
     {
         return _weight_format;
@@ -354,6 +362,22 @@ public:
     {
         _weight_format = weight_format;
     }
+    /** Flag which specifies if the GEMM operation is running in f16 matmul with f32 accumulation.
+     *
+     * @return True if the GEMM operation is running in f16 matmul with f32 accumulation else false.
+     */
+    bool use_fp32_acc() const
+    {
+        return _use_fp32_acc;
+    }
+    /** Set use_fp32_acc flag
+     *
+     * @param[in] use_fp32_acc set wheter or not to use f32 accumulation in f16 matmul
+     */
+    void set_use_fp32_acc(bool use_fp32_acc)
+    {
+        _use_fp32_acc = use_fp32_acc;
+    }
 
 private:
     bool                      _is_a_reshaped;
@@ -372,6 +396,7 @@ private:
     bool                      _fixed_format;
     arm_compute::WeightFormat _weight_format;
     bool                      _accumulate;
+    bool                      _use_fp32_acc;
 };
 } //namespace arm_compute
 #endif // ACL_ARM_COMPUTE_FUNCTION_INFO_GEMMINFO_H
