@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2018-2019 Arm Limited.
+ * Copyright (c) 2018-2019, 2025 Arm Limited.
  *
  * SPDX-License-Identifier: MIT
  *
@@ -21,8 +21,12 @@
  * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
  * SOFTWARE.
  */
-#ifndef ARM_COMPUTE_GRAPH_GROUPED_CONVOLUTION_MUTATOR_H
-#define ARM_COMPUTE_GRAPH_GROUPED_CONVOLUTION_MUTATOR_H
+#ifndef ACL_ARM_COMPUTE_GRAPH_MUTATORS_GROUPEDCONVOLUTIONMUTATOR_H
+#define ACL_ARM_COMPUTE_GRAPH_MUTATORS_GROUPEDCONVOLUTIONMUTATOR_H
+
+/** @file
+ * @publicapi
+ */
 
 #include "arm_compute/graph/IGraphMutator.h"
 
@@ -44,4 +48,4 @@ public:
 };
 } // namespace graph
 } // namespace arm_compute
-#endif /* ARM_COMPUTE_GRAPH_GROUPED_CONVOLUTION_MUTATOR_H */
+#endif // ACL_ARM_COMPUTE_GRAPH_MUTATORS_GROUPEDCONVOLUTIONMUTATOR_H
