@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2017-2022 Arm Limited.
+ * Copyright (c) 2017-2022, 2025 Arm Limited.
  *
  * SPDX-License-Identifier: MIT
  *
@@ -21,8 +21,12 @@
  * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
  * SOFTWARE.
  */
-#ifndef ARM_COMPUTE_CLTUNER_H
-#define ARM_COMPUTE_CLTUNER_H
+#ifndef ACL_ARM_COMPUTE_RUNTIME_CL_CLTUNER_H
+#define ACL_ARM_COMPUTE_RUNTIME_CL_CLTUNER_H
+
+/** @file
+ * @publicapi
+ */
 
 #include "arm_compute/core/CL/OpenCL.h"
 #include "arm_compute/core/utils/misc/Macros.h"
@@ -124,10 +128,6 @@ public:
     void tune_kernel_static(ICLKernel &kernel) override;
     void tune_kernel_dynamic(ICLKernel &kernel) override;
     void tune_kernel_dynamic(ICLKernel &kernel, ITensorPack &tensors) override;
-#if defined(ENABLE_EXPERIMENTAL_DYNAMIC_FUSION)
-    void tune_kernel_dynamic(ICLKernel &kernel, ITensorPack &tensors, const experimental::dynamic_fusion::ClExecutionDescriptor &exec_desc) override;
-#endif // defined(ENABLE_EXPERIMENTAL_DYNAMIC_FUSION)
-
     /** Is the kernel_event set ?
      *
      * @return true if the kernel_event is set.
@@ -157,9 +157,9 @@ private:
 
     std::unordered_map<std::string, CLTuningParams> _tuning_params_table;
     std::unordered_map<std::string, cl::NDRange>    _lws_table;
-    cl::Event    _kernel_event;
-    bool         _tune_new_kernels;
-    CLTuningInfo _tuning_info;
+    cl::Event                                       _kernel_event;
+    bool                                            _tune_new_kernels;
+    CLTuningInfo                                    _tuning_info;
 };
 } // namespace arm_compute
-#endif /*ARM_COMPUTE_CLTUNER_H */
+#endif // ACL_ARM_COMPUTE_RUNTIME_CL_CLTUNER_H
